==> auth-api-5.1.0-sources.jar: de/alpharogroup/auth/enums/ValidationErrors.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2015 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.auth.enums;

/**
 * The enum {@link ValidationErrors} holds error constants that can occur over the sign up or sign
 * in process.
 */
public enum ValidationErrors
{
	/** Indicates that the term of use are not accepted. */
	TERM_OF_USE_ERROR,
	/** Indicates that the email already exists. */
	EMAIL_EXISTS_ERROR,
	/** Indicates that the username already exists. */
	USERNAME_EXISTS_ERROR,
	/** Indicates that the passwords are uneqaul. */
	UNEQAUL_PASSWORDS_ERROR
};

==> auth-api-5.2.1-sources.jar: de/alpharogroup/auth/enums/ValidationErrors.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2015 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.auth.enums;

/**
 * The enum {@link ValidationErrors} holds error constants that can occur over the sign up or sign
 * in process.
 */
public enum ValidationErrors
{
	/** Indicates that the email already exists. */
	EMAIL_EXISTS_ERROR,
	/** Indicates that the term of use are not accepted. */
	TERM_OF_USE_ERROR,
	/** Indicates that the passwords are uneqaul. */
	UNEQAUL_PASSWORDS_ERROR,
	/** Indicates that the username already exists. */
	USERNAME_EXISTS_ERROR
};
